Acknowledging the TOM Toolkit
-----------------------------

We hope you find our software useful for your research.  If so, we would be grateful
if you can include a brief acknowledgement in your papers and presentations, for example
"This research made use of `The TOM Toolkit <https://tom-toolkit.readthedocs.io/>`_".
We would also very much appreciate you including a citation to our paper describing
the Toolkit `Street, R.A. et al., 2018, SPIE, 10707, 11 <http://adsabs.harvard.edu/abs/2018SPIE10707E..11S>`_
(to export the BibTeX please click `here <https://ui.adsabs.harvard.edu/abs/2018SPIE10707E..11S/exportcitation>`_).
